# Contributor Covenant Code of Conduct

## ⭐ Our Pledge

We as members, contributors, and leaders pledge to make participation in our project and community a harassment-free experience for everyone, regardless of age, body size, disability, ethnicity, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, religion, or sexual identity and orientation.

We pledge to act and interact in ways that contribute to an open, welcoming, diverse, inclusive, and healthy community.

---

## ⭐ Our Standards

Examples of behavior that contributes to a positive environment:
- Using welcoming and inclusive language.
- Being respectful of differing viewpoints and experiences.
- Accepting constructive criticism gracefully.
- Showing empathy toward other community members.

Examples of unacceptable behavior:
- The use of sexualized language or imagery and unwelcome sexual attention.
- Trolling, insulting or derogatory comments, and personal or political attacks.
- Public or private harassment.
- Publishing others' private information (e.g. physical or electronic address) without explicit permission.
- Other conduct which could reasonably be considered inappropriate.

---

## ⭐ Enforcement Responsibilities

Project maintainers are responsible for clarifying and enforcing standards of acceptable behavior and will take appropriate corrective action in response to any instances of unacceptable behavior.

---

## ⭐ Scope

This Code of Conduct applies within all project spaces, including issues, pull requests, and all communication channels (e.g. discussions, Slack, etc.).

---

## ⭐ Attribution

This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org), version 2.1.
